@@ -15,25 +15,23 @@ flush(stderr()); flush(stdout())
 ### Title: Catalogues of regular 128 run designs of various factor numbers
 ### Aliases: Catalogues catlg128.8to15 catlg128.16 catlg128.17 catlg128.18
 ###   catlg128.19 catlg128.20 catlg128.21 catlg128.22 catlg128.23
-###   catlg128.24
+###   catlg128.24 catlg128.25 catlg128.26to33
 ### Keywords: array design
 
 ### ** Examples
 
-data(catlg128.8to15)
 catlg128.8to15[1:5]
 
-## example of using the large catalogue
+## example of using a catalogue from this package with function FrF2
 ## the design in the example will also be found with the default catalogue
-    ## because arrays for all compromise plans have been added to catlg with 
-    ## FrF2 version 1.1-1
-## not run because it takes very long because of the large catalogue
+    ## because arrays for all compromise plans with up to 24 factors 
+    ## have been added to catlg with FrF2 version 1.1-1
+## from package FrF2 1.6-5 onwards, package FrF2.catlg128 need not be loaded 
+## for the code below to work
 ## Not run: 
-##D data(catlg128.23)
-##D length(catlg128.23)
-##D plan <- FrF2(128, 23, estimable=compromise(23,1)$requirement, select.catlg=catlg128.23)
+##D plan <- FrF2(128, 23, estimable=compromise(23,1:2)$requirement, select.catlg=catlg128.23)
 ##D summary(plan)
-##D rm(catlg128.23)
+##D length(catlg128.23)
 ## End(Not run)
 
 
